| NADPgeo | R Documentation |
Location data for all sites currently or formerly active in the NTN network.
data(NADPgeo)
An object of class "cross"; see read.cross.
National Atmospheric Deposition Program (NRSP-3). 2019. NADP Program Office, Wisconsin State Laboratory of Hygiene, 465 Henry Mall, Madison, WI 53706. (NADP/NTN)
data(NADPgeo) Latitude <- attr(NADPgeo, "Latitude (DD)") siteID <- NADPgeo$`Site ID`
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.