lambertWtransform: Returns LambertW transformed residuals

lambertWtransformR Documentation

Returns LambertW transformed residuals

Description

Returns LambertW transformed residuals

Usage

lambertWtransform(dfRes, plotMulti, writeMat)

Arguments

dfRes

Dataframe of residuals (can take NA values)

plotMulti

Binary, TRUE to plot the multivariate qq plot

writeMat

Binary, TRUE to write a mat file of the resulting covariance matrix with the name "covSitesLambertW.mat"

Value

Returns a dataframe of LambertW transformed residuals, multivariate and univariate variables analysis, and the resulting covariance matrix

Examples

lambertWtransform(data.frame(matrix(runif(n = 100), ncol = 5 )),plotMulti = FALSE, writeMat = FALSE)

hessakh/MESgenCov documentation built on Feb. 3, 2023, 1:09 a.m.