| lambertWtransform | R Documentation |
Returns LambertW transformed residuals
lambertWtransform(dfRes, plotMulti, writeMat)
dfRes |
Dataframe of residuals (can take NA values) |
plotMulti |
Binary, TRUE to plot the multivariate qq plot |
writeMat |
Binary, TRUE to write a mat file of the resulting covariance matrix with the name "covSitesLambertW.mat" |
Returns a dataframe of LambertW transformed residuals, multivariate and univariate variables analysis, and the resulting covariance matrix
lambertWtransform(data.frame(matrix(runif(n = 100), ncol = 5 )),plotMulti = FALSE, writeMat = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.